@@ -41,7 +41,7 @@ const int MAIL_MIN_LINES = 4;   // allow for From, To, no CC, Date, Subject
 namespace KAlarmCal
 {
 
-class AlarmText::Private
+class Q_DECL_HIDDEN AlarmText::Private
 {
 public:
     enum Type { None, Email, Script, Todo };
@@ -92,11 +92,11 @@ void AlarmText::Private::initialise()
 {
     if (!mInitialised) {
         mInitialised     = true;
-        mFromPrefixEn    = QLatin1String("From:");
-        mToPrefixEn      = QLatin1String("To:");
-        mCcPrefixEn      = QLatin1String("Cc:");
-        mDatePrefixEn    = QLatin1String("Date:");
-        mSubjectPrefixEn = QLatin1String("Subject:");
+        mFromPrefixEn    = QStringLiteral("From:");
+        mToPrefixEn      = QStringLiteral("To:");
+        mCcPrefixEn      = QStringLiteral("Cc:");
+        mDatePrefixEn    = QStringLiteral("Date:");
+        mSubjectPrefixEn = QStringLiteral("Subject:");
     }
 }
 
@@ -316,7 +316,7 @@ unsigned long AlarmText::kmailSerialNumber() const
 */
 QString AlarmText::summary(const KAEvent &event, int maxLines, bool *truncated)
 {
-    static const QRegExp localfile(QLatin1String("^file:/+"));
+    static const QRegExp localfile(QStringLiteral("^file:/+"));
     QString text;
     switch (event.actionSubType()) {
     case KAEvent::AUDIO:
@@ -448,7 +448,7 @@ QString AlarmText::fromCalendarText(const QString &text, bool &email)
             int i = text.indexOf(Private::mSubjectPrefixEn);
             i = text.indexOf(QLatin1Char('\n'), i);
             if (i > 0) {
-                dispText += text.mid(i);
+                dispText += text.midRef(i);
             }
             email = true;
             return dispText;
@@ -489,7 +489,7 @@ QString AlarmText::toCalendarText(const QString &text)
             int i = text.indexOf(Private::mSubjectPrefix);
             i = text.indexOf(QLatin1Char('\n'), i);
             if (i > 0) {
-                calText += text.mid(i);
+                calText += text.midRef(i);
             }
             return calText;
         }
